Module metadata

Module metadata 

This module includes ways to get metadata attached to profiling reports.

Modules

awsaws-metadata-no-defaults
Contains functions for getting host metadata from IMDS

Structs

Duration
A Duration type to represent a span of time, typically used for system timeouts.
Ec2AgentMetadataBuilder
Builder for EC2 agent metadata
FargateAgentMetadataBuilder
Builder for Fargate agent metadata
OrderedF64
An ordered float. Individual type to avoid public API dependencies.
ReportMetadata
Metadata associated with a specific individual profiling report

Enums

AgentMetadata
Host Metadata, which describes a host that runs a profiling agent. The current set of supported agent metadata is AWS-specific. If you are not running on AWS, you can use AgentMetadata::NoMetadata.