Module aws

Module aws 

Available on crate feature aws-metadata-no-defaults only.
Contains functions for getting host metadata from IMDS

Enums

AwsProfilerMetadataError
An error getting IMDS metadata
FargateMetadataToAgentMetadataError
An error converting Fargate IMDS metadata to Agent metadata. This error should probably not happen except in case of a bug in either this crate or IMDS.

Functions

load_agent_metadata
Load agent metadata from Fargate or IMDS.