Module profiler

Module profiler 

A profiler that periodically uploads profiling samples of your program to a Reporter

Structs

Profiler
Rust profiler based on async-profiler.
ProfilerBuilder
Builds a Profiler, panicking if any required fields were not set by the time build is called.
ProfilerOptions
Options for configuring the async-profiler behavior. Currently supports:
ProfilerOptionsBuilder
Builder for ProfilerOptions.
RunningProfiler
A handle to a running profiler
RunningProfilerThread
A handle to a running profiler, running on a separate thread.

Enums

SpawnError
An error that happened spawning a profiler
SpawnThreadError
An error from Profiler::spawn_thread