LocalReporter

Struct LocalReporter 

pub struct LocalReporter { /* private fields */ }
A reporter that reports into a directory.

The files are reported with the filename yyyy-mm-ddTHH-MM-SSZ.jfr

Unlike other reporters (e.g. S3), the local reporter will flush any pending JFR data on drop when the profiler task is cancelled (for example, during Tokio runtime shutdown). Other reporters require an explicit call to RunningProfiler::stop to ensure the last sample is uploaded.

It does not currently use the metadata, so if you are using LocalReporter alone, rather than inside a MultiReporter, you can just use AgentMetadata::NoMetadata as metadata.

Example

let profiler = ProfilerBuilder::default()
   .with_local_reporter("/tmp/profiles")
   .build();
let profiler = profiler.spawn_controllable()?;
// ... your program goes here
profiler.stop().await; // make sure the last profile is flushed

Implementations

Source

impl LocalReporter

pub fn new(directory: impl Into<PathBuf>) -> Self

Instantiate a new LocalReporter writing into the provided directory.