This module includes ways to get metadata attached to profiling reports.
Modules
Structs
- Duration
- A
Durationtype to represent a span of time, typically used for system timeouts. - Ec2Agent
Metadata Builder - Builder for EC2 agent metadata
- Fargate
Agent Metadata Builder - Builder for Fargate agent metadata
- Ordered
F64 - An ordered float. Individual type to avoid public API dependencies.
- Report
Metadata - Metadata associated with a specific individual profiling report
Enums
- Agent
Metadata - Host Metadata, which describes a host that runs a profiling agent. The current set of supported agent metadata is AWS-specific. If you are not running on AWS, you can use AgentMetadata::NoMetadata.