A profiler that periodically uploads profiling samples of your program to a Reporter
Structs
- Profiler
- Rust profiler based on async-profiler.
- Profiler
Builder - Builds a
Profiler, panicking if any required fields were not set by the timebuildis called. - Profiler
Options - Options for configuring the async-profiler behavior. Currently supports:
- Profiler
Options Builder - Builder for
ProfilerOptions. - Running
Profiler - A handle to a running profiler
- Running
Profiler Thread - A handle to a running profiler, running on a separate thread.
Enums
- Spawn
Error - An error that happened spawning a profiler
- Spawn
Thread Error - An error from
Profiler::spawn_thread